@@ -30,8 +30,8 @@ class gsheet:
         sheet_page.append_row(list_value)
 
 class gdrive:
-    def download(self, id):
+    def download(self, id, quiet_mode=True):
         url = requests.get(f'https://drive.google.com/file/d/{id}/view?usp=sharing', headers = {'User-Agent': 'Mozilla/5.0','Content-Type': 'application/x-www-form-urlencoded','Referer': 'https://www.investing.com/equities/credit-agricole-technical','X-Requested-With': 'XMLHttpRequest'})
         soup = BeautifulSoup(url.content, 'html.parser')
         filename = soup.find('title').text.split()[0]
-        gdown.download(f'https://drive.google.com/uc?id={id}', f'{filename}', quiet=False)
\ No newline at end of file
+        gdown.download(f'https://drive.google.com/uc?id={id}', f'{filename}', quiet=quiet_mode)
\ No newline at end of file
